use std::sync::{Arc, Mutex};

use crate::{lox_context, DbConfig};
use chrono::{naive::Days, DateTime, Local, NaiveDateTime, Utc};
use lox_library::{BridgeAuth, BridgeDb};
use sled::IVec;

pub struct DB {
    db: sled::Db,
}

impl DB {
    pub fn write_context(&mut self, context: lox_context::LoxServerContext) {
        let date = Local::now().format("context_%Y-%m-%d_%H:%M:%S").to_string();
        let json_result = serde_json::to_vec(&context).unwrap();
        println!("Writing context to the db with key: {:?}", date);
        let _new_ivec = self.db.insert(
            IVec::from(date.as_bytes().to_vec()),
            IVec::from(json_result.clone()),
        );
        assert_eq!(
            self.db
                .get(IVec::from(date.as_bytes().to_vec()))
                .unwrap()
                .unwrap(),
            IVec::from(json_result)
        );
    }

    pub fn open_new_or_existing_db(
        db_config: DbConfig,
        roll_back_date: Option<String>,
    ) -> Result<(DB, lox_context::LoxServerContext), sled::Error> {
        let context: lox_context::LoxServerContext;
        let (lox_db, context) = match sled::open(db_config.db_path) {
            Ok(lox_db) => {
                // Check if the lox_db already exists
                if lox_db.was_recovered() {
                    context = read_lox_context_from_db(lox_db.clone(), roll_back_date);
                //Otherwise, create a new Lox context
                } else {
                    let new_db = BridgeDb::new();
                    let new_ba = BridgeAuth::new(new_db.pubkey);
                    context = lox_context::LoxServerContext {
                        db: Arc::new(Mutex::new(new_db)),
                        ba: Arc::new(Mutex::new(new_ba)),
                        extra_bridges: Arc::new(Mutex::new(Vec::new())),
                        to_be_replaced_bridges: Arc::new(Mutex::new(Vec::new())),
                    };
                }
                (DB { db: lox_db }, context)
            }
            Err(e) => {
                panic!("Unable to read or create lox database! {:?}", e);
            }
        };
        Ok((lox_db, context))
    }
}

fn read_lox_context_from_db(
    lox_db: sled::Db,
    roll_back_date: Option<String>,
) -> lox_context::LoxServerContext {
    let context: lox_context::LoxServerContext;
    // Check if there is a roll back date and try to choose the appropriate context
    // to rollback to, otherwise, take the last saved context
    match roll_back_date {
        // If roll back date has been specified, either the exact date or range should be set
        Some(roll_back_date) => {
            // If the date is specified and it's in the database, use that to populate the context
            if lox_db.contains_key(roll_back_date.clone()).unwrap() {
                // Find date/time in db and use the context from that date.
                let ivec_context = lox_db
                    .get(IVec::from(roll_back_date.as_bytes().to_vec()))
                    .unwrap()
                    .unwrap();
                context = serde_json::from_slice(&ivec_context).unwrap();
                println!("Successfully used exact key {:?}", roll_back_date);
            } else {
                // If the exact date is not found, compute the start of the range as 24 hours prior to the specified date
                match compute_startdate_string(roll_back_date.clone()){
                    Some(start_date) => {
                        let start_date = start_date.format("context_%Y-%m-%d_%H:%M:%S").to_string();
                        let r: sled::Iter = lox_db.range(IVec::from(start_date.as_bytes().to_vec())..IVec::from(roll_back_date.as_bytes().to_vec()), );
                        match r.last(){
                            Some(entry) => {
                                let ivec_context = entry.unwrap();
                                let key: String = String::from_utf8(ivec_context.0.to_vec()).unwrap();
                                println!("Successfully used range and key {:?}", key);
                                context = serde_json::from_slice(&ivec_context.1).unwrap();
                            },
                            //If no entries are found within the 24 hours prior to the specified date, Exit
                            None => panic!("UNEXPECTED DATE: No entries found in the 24 hours prior to the input roll_back_date"),
                        }
                    }
                    None => panic!("UNEXPECTED DATE: Tried to use input date to calculate 24 hour range but failed. Exiting."),
                }
            }
        }
        // Use the last entry to populate the Lox context if no rollback date is set (which should be most common)
        None => {
            context = use_last_context(lox_db);
        }
    }
    context
}

fn compute_startdate_string(date_range_end: String) -> Option<DateTime<Utc>> {
    let parsed_end =
        NaiveDateTime::parse_from_str(&date_range_end, "context_%Y-%m-%d_%H:%M:%S").unwrap();
    let dt = DateTime::<Utc>::from_naive_utc_and_offset(parsed_end, Utc);
    dt.with_timezone(&Utc).checked_sub_days(Days::new(1))
}

fn use_last_context(lox_db: sled::Db) -> lox_context::LoxServerContext {
    let ivec_context = lox_db.last().unwrap().unwrap();
    let ivec_date: String = String::from_utf8(ivec_context.0.to_vec()).unwrap();
    println!("Using last context with date: {:?}", ivec_date);
    serde_json::from_slice(&ivec_context.1).unwrap()
}

#[cfg(test)]
mod tests {
    use super::lox_context::LoxServerContext;
    use super::DB;
    use super::DbConfig;

    #[test]
    fn test_write_context() {
        let (mut lox_db, _context) = DB::open_new_or_existing_db(DbConfig::default(), None).unwrap();
        assert!(
            lox_db.db.is_empty(),
            "db read from context that shouldn't exist"
        );
        let test_string = "{\"db\":{\"keypair\":[201,84,79,188,183,80,124,38,24,57,74,101,168,234,97,113,45,2,27,227,236,170,128,86,236,16,167,242,10,166,252,90,4,176,236,14,247,73,94,98,246,65,69,32,32,82,12,127,18,85,244,194,243,248,95,15,35,105,203,156,11,111,19,29],\"pubkey\":[4,176,236,14,247,73,94,98,246,65,69,32,32,82,12,127,18,85,244,194,243,248,95,15,35,105,203,156,11,111,19,29],\"openinv_buckets\":[4,5,9,7,8],\"distributed_buckets\":[3],\"current_k\":1},\"ba\":{\"lox_priv\":{\"x0tilde\":[85,41,72,109,86,46,81,9,210,97,10,49,74,248,36,92,65,58,213,176,216,158,218,104,12,74,2,195,125,21,181,2],\"x\":[[123,196,110,59,160,128,12,49,184,235,21,191,5,211,238,241,140,17,45,124,43,0,132,200,245,60,39,231,171,103,1,1],[128,1,189,179,132,58,53,239,39,140,129,8,248,214,198,30,108,62,192,126,180,213,186,2,122,251,125,209,115,123,62,15],[23,138,233,141,142,126,154,226,142,12,251,164,251,235,56,66,235,183,113,251,33,16,26,201,119,40,206,152,127,72,25,11],[61,94,54,105,111,7,90,98,138,16,180,84,221,166,224,139,241,221,247,49,103,91,79,78,3,241,79,175,62,181,179,7],[120,251,196,223,77,58,205,154,26,78,186,178,178,26,70,203,123,55,136,128,106,95,213,141,119,124,16,40,24,66,193,10],[107,64,82,11,205,92,33,21,141,85,186,19,166,69,198,15,69,18,244,229,212,214,243,124,239,128,153,97,174,221,195,1],[89,185,222,176,72,23,67,104,75,194,113,15,48,236,71,181,122,80,144,167,218,253,41,59,59,248,243,4,191,74,203,9]]},\"lox_pub\":{\"X\":[[124,86,226,73,90,65,51,142,228,106,134,73,243,140,30,66,95,245,111,108,13,103,241,221,222,231,4,202,168,86,75,120],[38,178,246,142,27,106,61,213,8,212,201,114,158,48,91,31,213,139,0,152,157,165,45,220,75,77,34,177,15,158,84,84],[152,36,2,34,71,93,87,173,89,7,250,213,65,242,146,194,137,188,157,123,228,102,85,130,78,34,117,55,113,100,200,101],[182,145,71,159,110,42,203,61,239,214,178,8,120,9,203,90,222,118,207,135,239,125,55,173,99,157,41,246,87,178,198,29],[134,145,250,125,207,137,246,47,213,61,137,28,254,57,36,198,112,81,117,8,126,177,35,72,5,2,175,116,117,7,246,0],[210,51,80,8,26,219,12,108,164,137,122,142,190,146,151,136,8,129,78,2,170,79,174,177,249,235,235,203,94,118,155,53],[12,214,157,115,201,64,215,118,158,108,77,219,253,222,33,248,17,233,225,150,231,193,160,51,21,1,21,109,157,36,28,54]]},\"migration_priv\":{\"x0tilde\":[181,29,215,96,118,231,180,229,98,80,101,106,72,144,19,165,214,253,0,50,245,213,91,27,185,48,159,234,38,205,147,14],\"x\":[[77,128,28,95,123,122,78,104,230,37,172,252,211,32,27,30,215,3,168,49,219,142,72,86,20,108,175,30,155,183,89,15],[131,213,100,130,177,195,196,157,155,94,160,42,146,56,244,21,21,225,217,124,223,129,208,238,72,179,222,1,22,197,80,10],[66,103,172,113,175,41,44,227,83,37,146,206,86,235,5,140,106,166,38,211,84,53,106,135,147,230,251,52,21,251,65,13],[108,44,131,107,94,121,95,238,253,225,133,200,239,190,181,29,95,141,65,201,188,140,162,41,20,49,240,249,160,188,86,8],[42,223,124,126,107,165,159,133,60,253,47,144,95,206,172,211,23,79,188,46,59,236,39,82,217,226,210,0,111,250,79,7]]},\"migration_pub\":{\"X\":[[118,3,198,185,75,234,119,161,104,244,73,220,137,14,215,106,71,172,9,105,43,196,212,8,175,36,231,13,244,150,99,5],[246,175,188,123,108,192,70,27,203,226,226,125,186,253,150,191,86,185,16,217,227,134,197,187,32,181,56,49,59,82,223,85],[106,236,9,177,125,238,13,89,118,20,190,146,180,51,246,198,153,111,55,73,233,53,16,171,145,122,200,97,173,95,49,0],[112,81,204,172,90,70,92,192,153,105,192,40,224,188,26,58,153,9,246,255,76,80,28,245,127,66,123,84,20,150,82,92],[4,67,164,55,135,180,11,122,35,219,138,108,243,185,19,6,147,165,191,82,17,143,254,177,218,101,126,58,80,116,16,54]]},\"migrationkey_priv\":{\"x0tilde\":[241,119,133,223,169,255,180,151,120,139,119,244,42,225,75,147,157,144,176,193,154,66,205,167,190,151,245,25,111,100,175,4],\"x\":[[13,164,109,8,131,170,158,121,184,95,70,236,244,54,248,30,190,152,40,147,143,174,215,76,62,125,59,140,56,46,191,11],[136,13,238,110,70,92,169,61,90,145,38,115,60,100,174,89,25,241,40,155,39,27,25,191,255,101,128,202,54,173,112,3],[138,178,205,1,214,251,19,220,100,169,146,87,169,247,92,135,238,214,176,115,68,248,98,151,249,223,250,127,86,126,12,5]]},\"migrationkey_pub\":{\"X\":[[124,62,91,180,173,88,176,18,50,126,217,90,115,135,56,148,1,192,49,122,145,106,15,41,102,132,104,250,58,171,246,54],[78,125,118,143,92,135,62,105,183,113,216,111,149,180,171,255,34,227,159,7,71,250,55,46,133,49,118,185,118,197,25,89],[78,35,14,23,16,87,161,203,241,129,68,15,113,149,188,78,43,44,6,124,8,241,37,72,206,77,203,95,107,240,212,51]]},\"reachability_priv\":{\"x0tilde\":[117,96,143,255,115,69,103,65,180,11,222,138,12,211,129,70,196,165,32,132,111,234,226,190,115,135,172,116,93,35,139,10],\"x\":[[119,97,187,188,31,54,247,119,178,12,12,107,184,112,163,180,127,41,50,115,88,36,46,241,178,98,38,147,91,139,215,13],[19,243,10,139,50,81,42,247,170,1,180,163,40,123,99,24,97,185,214,254,229,122,92,193,84,125,54,74,203,205,0,4],[215,156,31,28,179,18,140,114,93,90,92,126,47,206,62,79,144,124,215,63,234,118,172,38,75,255,55,215,176,106,108,1]]},\"reachability_pub\":{\"X\":[[84,50,132,41,247,148,208,142,47,191,111,107,107,249,22,184,183,97,242,239,209,107,161,248,237,242,25,247,38,231,65,85],[246,109,19,64,148,150,196,224,215,0,169,198,188,68,79,69,166,189,220,30,64,12,104,115,111,120,17,187,83,238,104,34],[4,55,132,2,213,114,25,101,140,205,249,190,133,60,136,18,151,227,59,104,193,186,158,45,212,128,216,235,165,104,1,50]]},\"invitation_priv\":{\"x0tilde\":[160,223,222,49,99,175,219,242,84,138,200,147,114,241,238,45,206,37,227,94,73,97,31,221,74,53,236,104,106,237,249,11],\"x\":[[115,220,229,104,149,88,90,188,19,134,95,138,124,14,20,46,21,40,29,180,189,230,161,121,167,96,239,154,76,148,155,1],[207,22,84,95,153,117,163,241,162,91,164,42,236,44,66,121,2,163,243,86,232,215,16,190,254,27,131,222,3,118,34,5],[2,3,80,235,190,114,154,191,83,34,55,51,94,31,28,101,96,93,148,91,132,48,166,229,9,186,121,221,141,199,173,15],[90,81,26,185,179,92,173,21,138,226,130,46,25,161,159,107,116,163,5,223,207,248,15,153,236,197,217,160,4,41,68,6],[207,133,200,240,250,195,202,205,125,76,69,62,14,233,171,22,218,147,203,41,114,236,218,149,75,104,115,48,236,233,72,6]]},\"invitation_pub\":{\"X\":[[174,173,72,99,191,209,97,186,7,72,159,230,209,29,82,215,129,206,27,244,114,36,115,14,60,160,193,189,241,115,113,23],[120,197,70,151,188,223,242,200,66,48,54,22,208,252,60,32,233,221,244,35,123,58,58,32,141,17,201,227,120,211,15,44],[52,96,210,153,126,87,72,56,210,157,108,14,237,179,235,160,81,195,92,147,244,54,190,176,55,84,203,238,53,145,248,19],[202,104,118,179,60,207,203,201,191,108,167,127,51,240,120,63,140,191,231,171,93,50,30,24,182,168,213,116,39,239,255,87],[158,22,194,92,254,206,129,69,181,161,240,206,129,234,144,103,229,172,53,28,109,114,24,97,168,64,143,179,70,14,42,69]]},\"bridgedb_pub\":[4,176,236,14,247,73,94,98,246,65,69,32,32,82,12,127,18,85,244,194,243,248,95,15,35,105,203,156,11,111,19,29],\"bridge_table\":{\"counter\":9,\"keys\":{\"2\":[234,125,15,48,43,93,107,32,129,111,101,99,74,171,94,115],\"8\":[37,31,162,20,37,170,152,183,229,227,188,141,11,190,93,81],\"9\":[142,198,20,243,148,87,181,35,76,215,162,102,149,194,20,47],\"5\":[94,127,85,8,145,157,65,81,60,193,214,239,212,222,208,192],\"7\":[253,41,25,218,229,23,96,223,162,65,198,161,93,255,41,204],\"1\":[4,216,218,48,7,174,74,108,19,195,193,104,111,225,227,24],\"3\":[253,81,46,66,147,94,161,254,83,218,184,56,240,178,129,153],\"6\":[28,114,248,173,187,78,104,166,243,182,17,110,24,91,123,97],\"4\":[139,137,67,18,169,40,232,253,97,72,129,245,96,13,102,168]},\"buckets\":{\"8\":[{\"addr\":[50,49,54,46,49,49,55,46,51,46,54,50,0,0,0,0],\"port\":63174,\"uid_fingerprint\":922068108643293997,\"info\":[116,121,112,101,61,115,99,114,97,109,98,108,101,115,117,105,116,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,70,68,56,68,67,55,69,70,57,50,70,49,70,49,52,68,48,48,67,70,57,68,54,70,54,50,57,55,65,51,52,54,56,66,53,57,69,55,48,55,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,83,111,109,101,40,123,34,112,97,115,115,119,111,114,100,34,58,32,34,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,50,51,52,53,54,55,34,125,41,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}],\"3\":[{\"addr\":[49,57,53,46,55,50,46,55,52,46,49,49,55,0,0,0],\"port\":28746,\"uid_fingerprint\":8013544061081454931,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,50,57,49,49,48,66,55,68,57,69,57,54,48,65,53,67,52,50,56,52,56,55,55,50,65,70,54,50,52,65,51,66,50,55,65,50,68,69,52,69,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,32,102,108,97,103,115,61,83,111,109,101,40,123,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}],\"7\":[{\"addr\":[49,57,49,46,49,56,48,46,49,48,51,46,50,51,54,0],\"port\":50309,\"uid_fingerprint\":17576062521251310994,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,70,68,56,68,67,55,69,70,57,50,70,49,70,49,52,68,48,48,67,70,57,68,54,70,54,50,57,55,65,51,52,54,56,66,53,57,69,55,48,55,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}],\"2\":[{\"addr\":[49,57,53,46,55,50,46,55,52,46,49,49,55,0,0,0],\"port\":28746,\"uid_fingerprint\":8013544061081454931,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,50,57,49,49,48,66,55,68,57,69,57,54,48,65,53,67,52,50,56,52,56,55,55,50,65,70,54,50,52,65,51,66,50,55,65,50,68,69,52,69,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,32,102,108,97,103,115,61,83,111,109,101,40,123,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[49,50,56,46,49,51,57,46,52,52,46,49,53,55,0,0],\"port\":10839,\"uid_fingerprint\":16072135124933872676,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,55,67,53,65,51,68,67,53,51,49,48,55,53,53,48,54,65,50,52,52,65,51,67,70,49,57,66,53,55,70,52,68,69,52,55,55,67,65,54,51,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[49,51,52,46,50,48,55,46,50,51,53,46,49,48,53,0],\"port\":9042,\"uid_fingerprint\":5838789323103363859,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,56,48,55,56,70,57,55,66,50,50,49,53,55,69,66,55,49,54,65,69,66,68,53,54,65,57,52,55,54,67,51,55,56,57,57,65,68,70,54,65,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}],\"4\":[{\"addr\":[49,50,56,46,49,51,57,46,52,52,46,49,53,55,0,0],\"port\":10839,\"uid_fingerprint\":16072135124933872676,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,55,67,53,65,51,68,67,53,51,49,48,55,53,53,48,54,65,50,52,52,65,51,67,70,49,57,66,53,55,70,52,68,69,52,55,55,67,65,54,51,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}],\"9\":[{\"addr\":[50,49,54,46,49,49,55,46,51,46,54,50,0,0,0,0],\"port\":63174,\"uid_fingerprint\":9189545078772697644,\"info\":[116,121,112,101,61,115,99,114,97,109,98,108,101,115,117,105,116,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,69,68,67,51,65,65,48,51,70,69,54,69,53,50,66,69,55,55,56,68,68,52,54,70,50,55,68,51,53,56,57,57,51,66,55,65,49,48,65,52,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,83,111,109,101,40,123,34,112,97,115,115,119,111,114,100,34,58,32,34,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,50,51,52,53,54,55,34,125,41,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}],\"5\":[{\"addr\":[49,51,52,46,50,48,55,46,50,51,53,46,49,48,53,0],\"port\":9042,\"uid_fingerprint\":5838789323103363859,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,56,48,55,56,70,57,55,66,50,50,49,53,55,69,66,55,49,54,65,69,66,68,53,54,65,57,52,55,54,67,51,55,56,57,57,65,68,70,54,65,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],\"port\":0,\"uid_fingerprint\":0,\"info\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}],\"1\":[{\"addr\":[50,49,50,46,49,54,54,46,49,54,54,46,54,55,0,0],\"port\":32414,\"uid_fingerprint\":3643046579853129326,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,66,48,56,49,49,56,65,56,48,68,55,54,54,66,65,57,65,56,70,57,65,55,50,50,67,50,54,54,49,52,69,48,54,66,56,54,69,52,67,65,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[49,51,50,46,49,56,49,46,49,53,53,46,55,54,0,0],\"port\":55241,\"uid_fingerprint\":4215620865531854407,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,67,66,70,56,51,51,51,49,54,53,70,49,67,51,53,65,68,70,48,54,66,70,52,50,53,49,48,52,69,56,51,51,65,68,68,65,49,54,53,66,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,32,102,108,97,103,115,61,83,111,109,101,40,123,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[49,53,54,46,55,50,46,50,49,57,46,52,57,0,0,0],\"port\":56030,\"uid_fingerprint\":8564141605929456761,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,68,56,66,67,67,48,69,67,70,69,50,67,57,54,53,65,66,67,50,57,67,54,50,55,70,68,67,69,67,48,66,48,54,67,53,65,68,66,49,54,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}],\"6\":[{\"addr\":[49,57,49,46,49,56,48,46,49,48,51,46,50,51,54,0],\"port\":50309,\"uid_fingerprint\":17576062521251310994,\"info\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,70,68,56,68,67,55,69,70,57,50,70,49,70,49,52,68,48,48,67,70,57,68,54,70,54,50,57,55,65,51,52,54,56,66,53,57,69,55,48,55,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},{\"addr\":[50,49,54,46,49,49,55,46,51,46,54,50,0,0,0,0],\"port\":63174,\"uid_fingerprint\":922068108643293997,\"info\":[116,121,112,101,61,115,99,114,97,109,98,108,101,115,117,105,116,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,70,68,56,68,67,55,69,70,57,50,70,49,70,49,52,68,48,48,67,70,57,68,54,70,54,50,57,55,65,51,52,54,56,66,53,57,69,55,48,55,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,83,111,109,101,40,123,34,112,97,115,115,119,111,114,100,34,58,32,34,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,50,51,52,53,54,55,34,125,41,0]},{\"addr\":[50,49,54,46,49,49,55,46,51,46,54,50,0,0,0,0],\"port\":63174,\"uid_fingerprint\":9189545078772697644,\"info\":[116,121,112,101,61,115,99,114,97,109,98,108,101,115,117,105,116,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,69,68,67,51,65,65,48,51,70,69,54,69,53,50,66,69,55,55,56,68,68,52,54,70,50,55,68,51,53,56,57,57,51,66,55,65,49,48,65,52,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,83,111,109,101,40,123,34,112,97,115,115,119,111,114,100,34,58,32,34,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,50,51,52,53,54,55,34,125,41,0]}]},\"encbuckets\":{\"4\":[243,219,179,57,84,182,40,215,251,37,203,204,99,245,55,82,26,47,170,128,85,194,171,108,79,73,178,160,48,41,178,118,20,198,82,162,99,91,229,66,254,152,22,109,194,79,223,116,188,96,129,98,218,76,209,69,21,11,137,109,125,187,195,203,229,202,93,69,16,167,98,206,228,205,41,169,234,20,253,164,110,3,127,84,162,112,204,99,7,27,64,225,42,137,155,12,141,140,129,8,47,83,47,91,116,110,211,171,108,247,100,73,11,203,200,49,110,219,197,36,220,210,84,167,104,229,209,178,223,243,106,195,242,156,224,120,206,105,113,74,113,114,75,58,29,155,27,159,226,201,113,12,187,246,246,55,81,137,41,81,114,255,230,159,77,14,143,152,255,63,186,59,42,243,189,136,127,186,125,95,116,2,20,80,185,56,192,97,30,32,252,114,158,112,77,212,76,77,138,124,249,201,104,22,66,124,199,75,96,40,9,241,79,152,69,211,155,203,84,101,251,94,120,212,64,41,144,111,127,76,32,233,225,196,182,57,178,39,234,185,41,137,111,135,36,40,3,200,107,72,63,198,102,206,22,147,114,116,77,165,221,176,126,202,77,228,186,2,153,58,115,187,35,128,99,251,209,27,52,70,58,185,196,39,29,228,232,137,107,165,239,185,63,190,194,62,58,233,224,161,247,181,110,148,166,167,31,107,198,227,199,248,221,135,150,80,128,253,53,239,65,15,244,184,108,155,8,135,220,182,140,130,240,200,206,109,218,134,69,15,55,18,43,164,137,9,19,69,21,73,121,164,160,119,98,188,128,95,76,177,215,135,80,0,208,97,74,173,194,147,175,145,200,239,47,236,148,10,145,152,20,13,99,48,1,168,227,115,175,10,160,86,139,21,63,115,147,16,72,181,16,17,103,184,18,182,177,28,13,210,221,163,31,36,181,108,163,73,60,7,11,219,35,195,136,51,168,65,99,193,226,108,76,20,178,211,138,12,50,67,24,23,118,34,251,38,142,4,47,140,177,158,115,17,99,112,33,165,182,49,17,27,200,56,83,18,84,159,248,128,103,28,87,222,167,184,61,54,44,24,7,78,60,254,60,133,139,45,4,189,100,240,236,9,27,209,235,193,123,51,1,224,192,43,171,119,31,147,134,222,75,222,175,158,97,84,151,252,94,234,111,234,174,58,34,155,97,224,118,119,107,56,174,248,235,20,25,74,180,167,235,59,70,134,181,52,169,123,84,12,244,139,44,127,227,16,66,32,101,246,219,146,162,220,91,142,100,196,25,106,235,16,121,82,44,179,15,137,136,203,172,221,245,15,9,48,225,0,63,73,198,205,35,129,244,222,131,168,136,90,133,216,77,180,110,125,77,78,205,116,60,120,181,62,170,75,17,159,203,233,83,0,180,20,148,222,236,232,142,143,59,106,56,183,133,106,240,132,247,70,71,208,96,0,127,76,141,139,15,143,231,95,224,171,112,168,141,85,9,76,50,234,3,179,76,155,188,52,56,158,80,103,191,226,204,134,83,110,1,173,105,52,213,233,226,26,92,21,186,154,47,43,62,220,89,19,74,254,191,42,205,121,146,171,171,226,110,50,225,199,200,148,13,49,80,31,209,159,242,83,44,207,7,6,140,222,82,164,91,116,155,1,72,179,82,133,214,6,110,20,110,52,102,102,183,171,179,227,244,111,80,161,50,66,61,122,51,7,82,77,185,156,53,136,173,132,200,156,137,227,31,71,231,143,88,220,216,200,96,37,94,36,100,150,136,22,90,223,130,36,91,69,210,241,141,146,78,52,180,87,3,66,110,34,67,203,2,122,148,237,219,210,83,190,41,230,112,157,206,53,173,131,81,147,99,172,139,232,106,200,46,39,88,63,155,187,214,183,33,63,109,180,157,56,53,32,166,217,45,88,155,112,116,58,36,195,57,5,47,212,72,25,204,148,99,212,192,20,164,68,250,17,14,86,204,58,142,33,178,217,37,153,76,94,215,84,176,180,237,132,44,89,121,192,233,209,179,226,242,239,54,229,0,80,78,93,209,162,143,169,144,189,153,236,17,196,120,91,169,143,120,186,105,246,170,67,151,22,105,91,53,202,84,220,67,78,172,26,189,198,63,134,196,236,106,251,220,151,96,86,23,98,79,115,3,73,152,115,184,116,66,223,109,175,217,253,194,180,166,148,36,246,60,3,174,193,139,86,208,169,194,105,215,106,105,172,83,147,12,185,249,151,241,107,182,164],\"7\":[121,116,166,201,156,46,185,47,24,40,165,223,229,251,190,116,128,130,33,81,2,157,253,153,154,74,232,248,187,174,231,135,184,149,226,227,156,41,28,164,243,190,172,24,41,215,93,207,173,52,151,5,10,176,166,217,37,136,199,3,20,4,175,115,184,48,222,208,198,87,221,183,16,136,98,187,176,248,38,192,127,187,241,110,131,41,27,7,142,121,88,226,177,134,18,55,185,212,220,3,97,4,109,200,0,74,234,152,102,131,204,54,56,66,112,157,152,93,136,51,230,214,213,25,30,152,20,132,80,98,74,184,48,218,62,169,99,81,41,150,127,145,38,199,159,117,9,30,111,156,249,48,136,112,190,158,237,242,135,131,144,45,164,249,224,132,4,61,156,237,51,247,214,114,217,91,241,65,253,197,12,174,59,248,2,178,149,31,177,46,131,45,69,65,204,187,50,214,131,138,192,95,96,128,15,13,42,85,23,185,73,144,94,167,211,102,67,79,97,112,9,155,28,176,249,141,145,51,113,72,174,106,105,44,117,9,17,251,22,224,68,180,188,19,214,202,215,157,135,55,188,173,124,92,85,195,116,14,75,94,96,19,208,8,250,61,62,54,228,122,152,30,113,185,123,125,120,6,171,5,185,185,210,52,24,120,17,48,87,42,146,195,226,134,113,63,195,116,161,21,94,102,40,248,134,172,97,117,40,229,153,170,58,78,207,62,255,139,175,77,199,228,28,159,186,231,80,142,199,7,35,161,74,215,63,249,2,3,185,41,7,97,224,252,2,160,217,97,208,17,20,141,247,31,125,2,145,235,2,158,203,110,69,151,39,9,110,101,212,205,73,70,65,170,114,202,169,94,226,118,212,30,52,205,122,244,48,123,97,11,94,149,70,205,183,111,183,141,213,110,93,167,99,195,173,203,79,53,55,2,58,171,220,188,224,173,20,106,114,34,81,179,210,86,48,9,51,237,134,154,209,66,79,164,140,38,151,49,69,205,188,255,64,233,124,84,229,200,83,109,238,79,135,33,41,92,156,108,193,177,1,150,116,242,203,126,159,224,32,12,214,205,138,139,51,52,149,136,99,11,42,250,32,53,131,117,146,163,152,122,77,250,8,10,144,178,95,126,237,230,188,64,128,254,198,45,91,46,19,177,217,179,140,5,156,150,207,72,42,202,66,35,245,44,254,49,80,113,228,236,8,160,78,141,159,235,242,161,49,215,18,49,40,123,211,173,51,181,206,55,149,46,74,220,219,156,92,229,255,69,52,39,109,55,253,80,97,231,186,119,161,23,163,135,20,89,224,177,187,78,226,171,222,80,231,206,246,175,68,214,12,229,172,131,2,98,125,40,165,163,209,23,191,86,112,188,229,86,126,180,27,118,119,219,24,7,124,100,238,129,147,83,115,148,50,186,227,27,132,38,84,127,203,52,177,119,230,170,54,224,27,106,91,138,52,173,151,126,0,140,17,238,38,128,12,120,114,10,127,45,168,2,45,8,191,185,48,137,126,187,146,42,123,122,63,53,230,69,5,0,225,24,210,176,218,86,138,141,191,236,19,87,228,170,106,5,53,142,235,186,172,17,50,70,60,221,45,188,172,33,103,7,112,181,147,149,215,47,160,181,167,229,198,98,142,199,171,226,119,148,50,130,159,44,21,78,117,162,114,56,249,52,39,65,242,27,164,248,114,102,46,98,249,15,222,13,42,170,173,230,99,50,242,166,63,69,162,218,217,210,135,20,229,91,141,29,28,22,222,225,212,219,188,123,87,96,161,36,34,5,77,7,55,39,52,212,195,205,66,16,3,20,7,199,206,120,12,158,223,215,65,47,76,87,173,255,142,70,83,153,189,81,24,23,211,54,103,19,25,146,75,127,252,234,132,102,138,184,79,189,253,103,60,180,12,179,49,135,105,53,180,139,42,158,171,38,12,108,18,51,198,125,243,60,44,108,182,189,127,101,101,56,82,207,224,133,71,75,227,11,227,52,146,93,229,164,36,146,247,168,102,150,115,239,124,188,189,241,172,50,250,140,156,223,125,36,248,106,68,220,24,147,126,101,36,244,34,108,157,252,72,57,130,15,70,7,3,111,149,71,61,214,243,102,201,93,127,121,110,203,115,209,219,149,109,68,177,76,31,156,9,253,161,64,236,155,179,235,127,247,209,121,160,209,175,254,206,39,7,14,119,81,35,239,232,125,81,98,85,222,79,195,26,44,142,210,155,90,68,74,52,41,11,148,102,27],\"6\":[244,11,101,22,78,170,71,140,99,116,217,44,131,218,253,82,90,97,68,119,33,138,170,25,164,190,131,162,170,130,3,115,91,101,207,203,27,103,99,248,246,203,7,214,173,158,5,215,199,207,161,55,192,114,167,194,205,252,80,76,161,125,10,92,4,247,32,164,73,105,221,40,138,56,166,126,231,204,121,157,253,200,142,239,212,137,173,73,218,19,66,60,61,176,141,89,224,119,3,4,36,142,4,196,171,46,175,142,137,245,239,137,71,161,111,63,83,144,208,234,84,80,130,63,187,102,192,102,249,30,74,27,68,35,15,147,199,67,118,57,187,187,48,205,198,34,147,0,55,119,146,202,227,70,68,159,176,148,248,249,1,185,134,153,178,42,132,57,165,76,230,15,182,29,201,23,201,5,15,29,4,52,19,246,224,218,120,175,76,240,32,211,180,222,185,158,217,252,238,226,216,177,246,113,69,185,93,84,143,239,179,205,26,248,166,7,17,236,57,88,49,192,147,28,40,34,190,53,87,4,208,237,209,69,68,86,231,185,11,27,255,118,64,250,123,183,49,211,48,146,59,37,46,199,114,234,143,148,165,232,93,126,9,31,42,92,241,8,221,191,41,107,150,220,236,234,239,170,13,4,215,99,10,153,34,81,23,27,102,47,246,83,135,198,49,231,105,117,209,21,17,167,46,151,250,192,150,231,234,33,53,143,139,160,219,172,41,144,120,149,36,190,92,177,23,33,209,157,229,181,102,118,74,38,11,152,232,43,121,20,72,204,40,251,107,239,224,211,120,85,229,22,232,155,92,146,181,112,61,181,213,10,51,52,91,159,160,162,176,170,64,132,50,203,67,231,148,254,52,103,156,133,5,175,181,71,34,49,78,141,15,163,150,151,132,195,149,49,110,61,95,239,79,82,78,147,210,246,106,102,107,195,107,225,219,115,169,18,10,203,213,180,134,146,227,164,213,190,180,11,193,4,44,56,182,101,238,176,224,193,69,71,169,223,23,1,17,12,20,80,137,61,214,238,145,85,115,156,125,176,84,157,171,60,4,177,54,190,219,178,182,25,65,206,253,14,117,110,196,196,29,44,54,131,128,76,77,165,133,61,239,175,25,244,180,143,235,110,182,117,86,215,253,226,252,211,107,81,74,184,192,211,95,95,38,163,23,47,246,216,138,87,237,108,11,143,177,111,199,133,161,144,9,114,53,208,41,13,28,139,234,198,210,206,204,184,126,118,96,253,182,253,247,231,213,160,117,255,198,116,94,153,119,34,18,91,40,95,65,176,215,1,115,105,166,73,58,230,136,204,30,109,134,64,249,92,207,138,170,115,56,40,20,215,175,39,105,237,224,63,233,250,186,89,118,227,118,47,176,21,194,207,245,182,78,158,31,237,77,145,111,24,66,228,5,38,218,184,91,25,193,153,90,233,8,224,127,102,37,135,198,206,102,253,224,193,243,100,59,182,146,206,185,168,69,101,201,160,237,192,33,246,202,119,49,33,33,75,244,255,142,145,49,235,108,246,211,166,87,5,21,104,239,95,104,195,15,31,130,58,32,172,118,159,3,166,35,48,126,88,51,226,194,173,130,76,249,36,244,43,120,3,1,40,219,39,208,119,235,178,252,48,159,144,157,36,243,196,9,33,118,79,178,119,232,28,160,132,35,81,244,209,96,168,146,133,206,161,103,120,138,133,254,96,103,139,19,29,213,190,153,69,217,164,26,64,163,51,232,144,78,167,113,209,72,47,230,111,183,79,97,178,67,96,105,255,17,155,89,106,42,1,75,4,21,87,82,43,82,105,74,65,100,165,92,203,73,37,31,196,189,11,142,81,26,119,148,198,148,211,97,4,36,34,12,63,209,12,49,175,224,199,90,3,70,250,241,252,248,142,231,149,240,220,183,27,214,28,9,154,15,187,205,190,222,28,172,80,198,88,110,60,2,239,88,63,222,110,47,203,23,96,215,58,188,150,14,221,231,191,170,106,183,227,146,136,132,54,173,126,155,231,45,167,101,0,110,97,121,3,169,62,82,250,125,246,32,32,94,35,215,115,123,1,66,39,205,26,145,248,249,190,162,133,10,239,105,172,31,185,122,2,161,244,90,37,56,204,249,210,94,110,9,106,71,189,149,37,247,18,209,3,4,36,50,13,159,227,253,5,215,15,86,66,171,214,67,12,22,54,132,69,9,255,47,113,75,152,137,29,21,240,144,127,35,186,150,3,66,213,153,77,109,154,142,210],\"5\":[233,196,158,255,98,84,122,36,218,215,121,163,96,106,42,88,230,167,14,88,179,219,50,169,25,90,3,145,244,37,23,242,225,67,131,245,126,150,236,250,28,245,185,107,7,131,111,93,225,78,186,159,39,191,187,218,192,164,9,120,45,193,155,75,198,116,203,52,233,122,253,76,21,94,26,159,69,197,235,231,185,49,184,7,190,41,190,9,96,34,67,18,205,120,50,81,16,52,238,13,173,27,134,22,9,63,238,163,64,35,207,37,123,66,114,186,180,47,172,31,121,231,196,120,160,82,198,254,20,99,103,102,197,70,162,72,65,158,175,191,145,13,62,108,92,195,56,168,121,109,24,233,67,231,116,49,140,242,20,126,200,100,90,239,183,139,250,6,157,223,92,203,174,49,50,126,91,10,154,70,34,149,153,82,45,14,15,99,140,71,103,168,208,121,58,253,203,23,150,146,156,243,98,202,111,129,67,203,126,198,188,209,3,170,64,242,91,19,253,236,157,35,134,212,5,235,118,48,90,178,198,46,89,139,64,236,253,13,171,40,68,165,104,2,97,6,33,137,150,11,43,161,21,189,202,98,98,95,204,124,82,80,199,101,163,168,181,160,148,232,178,32,216,99,17,145,198,154,147,194,20,31,144,190,235,132,158,218,7,80,131,97,123,158,16,220,202,226,177,139,112,10,108,97,150,214,70,26,190,107,190,57,214,236,29,184,24,84,204,35,67,89,155,81,135,229,19,201,82,125,68,29,217,216,175,198,194,9,95,178,152,194,34,25,19,241,213,234,60,13,139,148,238,184,10,208,78,59,174,93,216,193,244,59,165,90,146,163,207,101,60,145,21,74,123,24,227,106,239,56,50,176,35,250,74,170,255,98,15,135,52,38,30,64,158,174,195,136,153,97,69,135,31,80,14,170,44,137,83,107,66,4,42,141,78,66,153,157,35,147,245,234,103,125,191,71,225,223,215,190,220,47,62,12,178,85,199,110,133,111,214,36,179,132,17,152,62,6,31,198,251,9,77,53,168,106,91,80,215,57,94,31,52,194,159,175,214,122,155,173,2,225,24,228,207,71,69,115,66,86,205,0,228,101,83,111,7,249,214,124,42,204,250,209,121,170,138,122,185,112,151,131,132,121,105,175,23,117,197,191,134,153,224,130,48,239,49,228,69,186,50,242,55,112,193,149,98,1,156,92,167,235,114,195,58,55,32,158,168,245,56,164,109,172,74,154,89,193,183,63,60,243,64,139,202,56,132,240,211,80,135,88,230,66,4,234,199,220,49,184,201,108,68,36,176,101,88,62,83,250,22,247,25,29,158,228,222,72,149,121,170,4,119,25,124,211,208,135,19,197,182,130,153,158,231,247,42,163,164,217,47,45,30,221,139,58,197,102,155,60,39,71,234,18,53,204,165,77,247,169,119,146,31,108,39,92,167,104,27,110,98,70,174,78,151,239,225,145,15,153,12,158,95,214,8,53,244,237,42,143,51,168,5,153,182,96,26,143,193,106,197,163,79,91,48,142,197,51,179,139,12,238,16,106,184,99,225,208,35,141,109,31,7,27,223,198,156,118,93,114,111,25,178,122,38,49,160,19,45,165,203,94,64,249,72,108,254,166,184,200,14,144,180,74,128,245,8,20,29,119,34,85,174,126,248,186,142,24,160,60,22,142,38,97,98,243,222,69,126,46,66,215,40,61,77,216,165,5,178,45,21,29,159,4,91,168,11,244,253,72,240,86,199,154,137,5,75,127,5,148,120,50,26,105,70,96,248,170,127,31,98,158,20,113,111,142,234,53,247,191,168,226,194,54,214,202,175,216,122,131,2,218,73,208,69,227,142,15,158,30,197,233,191,69,5,255,237,78,64,82,35,145,202,24,134,131,183,31,87,213,246,158,74,122,251,36,5,116,138,224,182,80,18,95,80,45,222,28,104,205,8,151,189,138,243,14,90,204,108,30,160,203,119,6,148,38,252,155,6,134,48,204,60,48,141,198,64,14,227,243,87,99,246,99,172,195,36,212,195,50,43,109,49,184,210,36,79,46,115,75,42,116,80,125,222,207,83,206,53,88,225,239,138,185,223,1,109,122,34,64,195,224,188,33,84,250,151,83,165,160,106,59,117,117,39,71,255,10,28,180,224,201,4,19,213,182,248,112,170,75,200,207,123,70,132,248,59,46,202,106,8,142,240,84,250,167,189,142,191,223,10,215,83,115,32,124,30,238,155,171,212,166,186,239,117,141],\"9\":[92,82,84,153,8,228,93,80,116,15,126,28,55,66,233,244,9,42,69,236,27,101,144,6,213,241,217,101,175,6,159,83,171,242,191,19,169,57,97,30,24,251,103,12,69,245,37,79,108,206,155,78,101,218,30,45,86,219,245,198,108,133,192,255,130,76,85,34,8,191,27,27,72,24,10,172,27,62,25,53,57,22,247,7,101,241,70,53,207,233,166,88,90,136,232,18,13,9,230,153,205,91,17,47,239,17,178,242,91,235,165,160,57,15,247,204,39,237,64,220,15,66,84,161,119,238,146,105,46,81,47,171,147,238,81,192,190,161,147,42,137,106,178,222,150,138,76,144,177,41,142,84,159,140,175,143,28,223,101,182,18,252,42,126,6,108,48,162,133,106,104,150,43,138,121,206,143,50,167,227,146,67,38,106,109,25,50,56,21,174,79,158,116,226,29,147,228,128,195,13,106,14,8,64,209,68,6,72,56,21,212,175,108,162,210,236,4,255,130,25,167,58,185,126,123,58,141,237,188,43,133,60,138,183,197,37,127,215,0,1,48,54,64,114,235,52,183,245,228,29,20,130,226,68,76,4,146,200,94,206,148,224,106,3,92,242,243,6,202,52,165,171,34,22,8,195,162,213,39,167,119,54,119,66,99,227,237,26,180,26,9,4,78,123,152,153,253,42,20,58,224,170,80,110,191,196,215,84,224,168,150,49,4,63,125,11,224,88,74,196,108,89,29,165,244,26,39,104,129,168,210,30,52,80,187,244,54,211,190,216,34,24,108,47,92,88,213,227,22,123,79,191,154,61,120,114,176,101,94,67,113,232,110,88,125,140,69,136,62,101,109,126,133,198,234,150,253,205,37,189,145,16,168,98,211,195,89,67,119,11,30,39,39,51,222,153,200,174,76,181,215,218,97,48,83,208,124,198,170,45,82,65,252,236,104,201,104,218,66,221,155,57,111,211,251,78,140,38,209,174,25,154,85,101,29,8,153,35,119,210,145,249,58,195,141,252,204,104,213,173,205,48,52,215,167,210,27,32,93,15,105,4,52,174,214,87,109,97,213,82,166,74,57,188,145,148,135,93,187,195,129,23,227,197,111,113,158,210,86,167,38,118,165,235,126,97,136,143,10,14,76,202,176,219,132,58,247,219,6,206,127,243,193,155,90,213,106,134,170,223,98,108,79,26,156,115,1,196,81,6,90,245,219,23,172,37,247,213,185,129,177,138,144,251,29,162,112,27,97,11,145,183,191,214,198,140,133,116,94,180,92,68,86,226,235,36,122,153,207,85,69,42,30,60,199,59,232,244,67,29,124,106,174,236,232,77,227,206,35,239,141,125,211,103,239,193,232,171,193,209,179,93,27,39,148,104,178,118,129,151,124,209,244,180,9,82,43,255,64,227,151,246,175,250,238,92,4,91,173,253,119,45,176,157,230,53,112,43,57,133,95,90,120,27,129,161,13,178,196,23,216,243,17,31,25,95,124,173,41,188,93,25,69,62,6,80,211,206,87,228,68,86,238,6,135,80,156,212,113,124,131,120,79,29,70,250,213,235,53,131,22,189,103,176,254,153,231,65,70,85,41,66,130,205,151,240,138,224,144,214,15,20,251,235,250,55,124,157,227,121,108,23,119,60,195,241,112,123,207,236,147,86,226,45,74,186,186,32,2,66,251,56,154,151,227,78,140,207,145,159,115,0,207,147,2,35,165,181,199,128,187,202,25,229,146,177,153,86,131,130,236,35,192,227,26,142,235,131,53,85,40,91,85,218,11,97,153,224,12,137,151,214,116,147,223,5,64,253,78,16,75,132,237,25,74,69,249,246,81,36,122,246,209,245,176,240,29,188,64,155,97,29,58,200,90,254,171,179,88,175,85,253,115,238,111,7,101,7,236,212,48,241,217,17,106,134,37,100,232,85,92,15,31,66,118,17,98,71,181,210,253,197,34,144,228,60,77,167,91,187,140,17,248,248,199,103,92,20,240,196,139,239,4,230,191,154,159,232,220,80,44,65,232,118,77,255,126,237,23,112,70,29,99,30,68,95,134,123,238,248,158,50,99,87,46,113,184,116,17,233,69,187,188,209,139,218,217,20,106,240,255,198,84,42,23,159,146,118,82,55,130,228,19,62,128,4,223,219,97,96,252,30,136,95,163,221,117,76,53,55,219,170,141,121,49,191,81,145,8,134,251,242,82,201,128,32,89,226,191,104,187,133,161,209,49,11,124,238,249,215,77,165,250,212,0,111],\"2\":[39,26,40,155,207,170,15,166,186,15,65,98,28,37,104,74,15,50,185,112,129,178,58,207,160,21,134,44,134,184,190,242,198,111,251,71,182,133,249,86,245,76,231,191,158,198,177,137,32,38,35,207,3,35,252,107,96,193,73,154,254,227,209,10,75,42,80,61,119,103,32,88,132,109,136,91,236,235,120,62,128,255,14,128,4,33,225,196,76,1,90,251,145,11,18,79,230,109,255,56,255,134,53,88,182,166,68,226,242,132,95,253,188,206,242,16,221,38,184,90,33,21,73,58,229,80,214,58,73,68,147,81,191,6,183,227,162,107,31,7,1,115,149,250,150,7,33,94,25,250,34,34,152,23,21,45,88,107,120,34,141,121,33,27,69,210,51,83,116,71,248,237,225,182,52,58,142,85,5,64,234,68,124,214,103,188,20,198,35,171,220,188,8,19,117,84,112,108,21,73,129,58,172,87,111,92,189,143,163,82,47,23,90,31,243,189,94,99,7,218,175,189,255,0,231,196,150,141,12,80,115,115,1,16,15,39,145,68,88,243,22,12,156,116,13,84,180,186,228,80,71,213,130,1,146,208,32,252,196,127,234,49,103,147,91,35,30,209,157,59,150,177,116,91,97,170,101,187,168,190,87,109,20,98,114,166,87,179,209,211,87,179,227,123,51,45,182,54,65,217,109,91,12,99,135,114,225,93,141,180,71,66,79,138,135,77,31,85,18,35,0,151,148,191,125,51,105,2,248,0,60,232,178,149,72,111,71,26,249,143,0,164,165,45,112,227,9,217,20,223,235,55,230,184,163,188,165,26,18,60,204,56,208,213,30,217,77,51,239,139,103,15,241,135,85,88,165,237,96,60,28,216,129,87,229,74,187,130,149,17,169,31,242,130,199,84,219,224,95,49,177,152,160,176,113,112,142,61,5,252,240,205,55,130,87,242,0,69,149,179,116,255,64,135,93,113,109,36,220,100,230,50,185,29,180,202,221,63,192,149,227,82,194,231,79,189,150,146,64,50,132,197,198,233,64,126,78,210,204,57,21,134,102,12,61,210,251,144,47,26,42,96,195,199,246,24,243,219,72,43,176,165,35,130,243,10,161,8,242,20,209,35,39,10,205,13,172,76,182,231,90,106,145,78,254,140,183,152,169,62,159,210,88,42,217,41,196,187,247,173,126,11,174,41,231,95,124,129,29,41,139,179,174,219,112,133,134,225,127,150,10,222,244,133,115,18,36,21,241,136,105,95,193,244,2,56,36,160,61,5,240,51,73,92,6,235,164,221,23,194,130,16,248,249,224,250,205,103,148,154,104,75,195,146,181,193,56,185,229,231,139,58,65,204,38,60,232,39,7,116,118,115,40,195,138,208,77,145,92,245,248,229,212,138,253,76,115,75,15,105,190,88,21,183,53,210,77,3,10,122,133,176,194,117,109,52,177,113,130,172,143,177,19,205,157,110,2,236,22,68,160,255,212,186,168,175,225,145,200,112,110,212,233,16,117,88,170,81,159,73,112,161,193,9,34,206,155,243,155,181,197,111,149,55,82,230,103,74,65,187,134,25,106,131,163,194,80,193,79,186,173,201,205,196,160,53,203,136,151,110,52,53,217,100,173,34,0,54,167,148,239,166,21,241,77,37,70,122,93,139,196,244,34,30,227,95,200,21,80,223,169,255,247,55,23,99,87,120,45,140,5,145,100,134,98,27,219,38,148,134,159,165,252,81,134,127,161,148,145,245,156,60,128,172,136,54,10,98,115,202,14,231,101,27,178,40,230,120,11,190,82,201,13,188,254,243,240,85,193,76,210,248,8,49,246,191,13,150,89,38,36,13,63,183,6,45,215,76,122,168,98,2,62,153,136,35,63,250,213,126,214,20,139,90,232,97,251,5,226,1,228,206,232,246,4,243,228,138,219,151,234,82,162,103,22,95,136,162,174,146,56,88,57,10,235,119,158,177,17,194,88,92,198,136,88,45,236,72,33,43,25,208,13,105,90,43,226,236,167,56,73,164,151,94,106,187,62,97,123,230,230,104,163,205,6,22,1,230,69,249,246,181,121,209,98,152,223,224,233,251,208,127,123,106,39,149,161,161,136,171,118,38,224,50,122,135,223,194,233,108,48,247,242,73,180,75,47,154,10,237,243,43,207,186,200,0,105,199,58,83,13,195,65,246,26,218,254,32,47,86,105,30,175,120,73,59,248,44,214,52,107,47,232,250,124,227,122,4,248,27,197,25,167,116,140,147],\"1\":[119,213,100,52,177,0,161,84,252,204,52,125,174,105,85,152,53,191,113,187,76,139,212,167,79,12,251,221,244,29,66,95,235,10,252,39,46,210,253,66,16,61,115,176,135,129,230,71,4,23,226,92,239,68,245,244,56,92,208,135,232,53,90,42,65,35,249,192,196,65,240,9,142,39,43,116,45,192,206,6,100,22,175,62,91,153,33,218,210,102,59,49,242,147,82,174,113,61,93,229,174,133,95,23,80,70,119,146,45,43,115,254,228,79,68,54,31,237,137,240,177,0,220,82,238,87,205,76,60,215,246,39,199,43,90,111,77,130,172,229,125,135,252,238,123,58,47,61,134,215,35,45,245,29,151,147,158,166,224,134,7,26,255,93,47,98,169,61,97,152,157,84,42,13,89,181,143,120,63,93,252,79,147,152,100,214,85,139,0,90,46,12,246,161,0,12,109,240,153,222,77,218,88,103,65,117,52,127,29,94,157,29,74,252,184,220,106,77,117,106,122,90,11,223,239,112,28,131,84,180,103,180,76,202,185,95,101,117,161,10,14,15,20,175,11,44,114,95,215,97,58,129,140,172,92,82,227,149,172,153,72,9,66,164,158,158,33,193,173,190,14,12,72,56,183,56,105,99,121,170,16,145,26,50,254,241,159,130,22,12,63,157,218,91,67,247,220,142,101,100,103,214,199,2,142,176,213,127,2,138,225,28,205,131,219,64,1,59,124,160,201,18,145,19,232,90,118,87,187,193,82,193,178,101,131,176,167,8,17,69,37,41,56,86,58,220,76,18,7,187,179,2,3,4,143,250,33,82,100,190,120,172,72,217,6,5,3,241,39,240,173,220,196,227,158,30,205,170,247,5,119,174,68,129,82,0,236,9,40,89,76,143,179,219,75,192,152,131,159,213,37,181,59,105,37,249,46,142,51,232,109,246,123,232,162,167,226,11,230,109,232,102,176,246,125,206,74,214,149,192,157,240,35,229,86,94,160,3,3,248,3,196,223,124,35,111,95,246,105,74,118,125,181,180,151,141,182,239,49,141,48,57,224,98,236,182,223,73,240,143,15,20,194,168,118,251,190,233,87,85,64,204,70,131,193,174,128,22,83,47,78,61,172,223,36,81,115,102,35,206,105,159,242,98,54,200,135,135,67,6,241,150,35,26,71,221,176,119,39,144,67,77,241,156,201,102,142,140,142,205,4,136,135,186,40,118,70,60,43,242,147,200,250,229,119,118,95,191,36,39,159,211,57,58,116,168,247,229,124,221,104,32,242,1,65,182,103,165,52,218,111,108,206,49,218,217,120,116,161,214,210,243,3,73,176,166,93,138,250,128,97,9,168,133,155,45,34,38,138,145,5,172,236,164,66,150,173,100,200,239,70,79,60,27,193,244,56,94,121,47,250,36,242,249,184,185,74,105,133,220,28,45,54,155,6,176,75,109,22,252,54,73,71,22,1,127,233,166,207,77,35,203,130,105,36,33,21,24,46,82,84,135,127,8,27,188,198,223,204,117,147,183,151,138,140,179,44,228,111,58,38,144,118,216,95,207,11,140,108,70,52,81,5,119,113,118,81,240,106,154,252,150,37,149,30,183,225,112,8,12,143,190,148,107,174,238,19,85,130,125,224,69,159,18,139,143,138,155,45,13,60,93,25,108,72,17,128,122,51,255,18,177,247,34,205,152,242,31,63,98,128,69,210,105,206,84,121,21,112,128,22,12,65,213,10,154,220,242,70,158,167,34,210,230,92,206,83,168,244,185,130,7,204,244,10,67,74,78,110,247,224,48,122,169,208,143,18,81,98,224,38,210,101,164,48,189,116,22,39,152,84,119,148,38,163,17,78,105,23,175,73,163,173,43,22,225,120,165,99,88,158,222,178,239,197,135,239,203,42,207,43,173,72,197,217,60,231,104,241,179,144,52,231,135,82,201,198,105,118,223,206,56,8,207,73,71,50,239,39,220,165,49,115,253,39,2,77,81,37,175,156,55,232,91,128,0,83,222,17,183,160,63,179,61,178,236,41,244,161,173,85,165,157,133,4,172,143,24,11,161,212,194,17,3,31,105,101,9,117,190,155,224,116,116,107,181,181,255,1,60,47,165,72,79,85,214,153,204,214,81,52,119,63,153,34,170,223,232,89,114,142,216,138,187,252,194,181,32,83,66,93,122,39,156,96,23,44,96,153,55,113,172,221,63,133,17,63,231,47,166,198,56,231,236,116,76,39,232,125,229,215,63,83,38,62,53],\"3\":[49,117,129,233,104,116,154,224,25,5,12,234,130,105,252,125,25,187,232,174,167,29,60,207,168,89,150,40,211,149,160,173,17,149,213,186,239,170,163,221,195,215,202,11,191,77,37,205,73,80,223,114,176,32,60,24,164,201,19,88,17,12,177,33,254,8,201,88,125,21,119,6,144,244,1,66,74,219,218,211,189,169,217,94,238,120,47,32,91,182,242,0,7,236,154,55,44,245,0,177,47,185,96,70,18,160,118,26,250,154,239,251,176,216,48,91,19,151,26,106,170,120,226,181,217,237,242,36,190,61,82,92,8,222,255,36,75,82,13,230,107,162,236,173,6,216,139,81,209,53,37,226,106,218,10,87,74,106,76,39,227,81,161,187,231,127,46,190,30,120,11,138,47,210,179,182,136,233,158,165,224,166,8,65,227,102,213,205,59,135,26,134,62,199,37,218,88,168,192,130,254,11,112,66,246,99,84,207,93,8,2,33,8,189,136,73,91,255,188,36,128,253,211,55,41,180,226,19,225,192,193,218,154,8,229,54,234,166,228,126,125,160,214,31,74,140,113,96,242,210,156,70,57,130,50,128,95,2,102,97,75,185,239,117,111,20,116,172,84,109,94,71,245,33,85,14,150,169,118,222,31,159,72,34,217,2,148,179,228,120,114,87,252,240,206,104,47,206,182,192,218,239,159,46,188,103,167,137,179,111,18,16,78,68,111,178,170,165,183,152,180,194,23,115,189,98,138,218,116,167,103,5,64,8,16,178,51,23,197,34,254,241,184,86,75,105,65,75,140,143,165,79,157,1,179,2,14,28,131,231,124,3,65,191,215,169,168,18,83,26,111,70,242,97,4,123,50,34,174,228,134,148,85,183,111,22,25,147,182,90,104,238,212,201,88,166,24,218,224,38,188,79,81,87,100,85,10,228,208,160,30,102,164,166,98,169,65,224,75,80,43,97,185,64,118,158,125,174,93,22,197,126,99,191,47,179,193,188,158,245,15,60,65,145,37,205,128,106,129,212,66,137,174,145,84,22,243,116,3,98,130,41,48,168,232,92,155,86,182,170,219,59,243,182,194,255,178,52,85,63,130,27,219,79,235,0,215,140,188,186,32,153,92,86,86,45,79,23,95,119,206,89,18,56,106,31,218,115,83,132,43,76,212,98,253,201,244,231,88,14,42,23,61,1,2,187,88,71,72,148,94,54,172,170,87,58,153,70,169,27,189,156,254,5,80,115,220,61,86,22,173,178,16,31,217,25,161,212,110,248,90,20,42,135,61,148,42,145,201,237,175,78,186,75,116,126,152,4,157,10,233,155,89,242,204,97,105,152,25,37,3,193,248,247,121,50,215,115,233,249,80,98,245,247,136,252,95,135,160,0,68,107,116,175,75,191,212,71,238,148,112,213,55,62,69,30,94,79,92,117,163,236,7,72,52,20,217,158,184,239,24,108,242,205,74,36,67,199,100,18,33,12,91,80,6,25,137,238,239,241,56,201,142,196,9,177,10,166,225,229,216,171,231,63,131,193,154,139,35,32,116,213,239,158,231,115,68,183,141,50,193,154,147,106,83,240,198,103,228,193,15,70,33,187,171,43,43,100,153,39,143,188,176,80,190,166,246,184,77,114,67,216,191,101,170,128,75,49,162,65,123,244,139,87,2,50,76,77,224,238,141,183,30,157,94,107,196,181,228,93,181,152,150,134,38,246,208,0,64,3,21,15,236,63,93,153,242,161,123,203,54,109,139,207,124,98,202,147,80,16,45,81,162,107,79,142,195,199,193,58,109,237,193,140,25,86,162,142,138,114,37,2,7,19,65,30,59,215,58,72,153,30,25,145,244,143,107,66,155,142,68,169,101,180,194,111,251,195,27,192,140,75,160,194,182,92,136,49,170,83,164,9,149,132,136,45,44,253,98,162,13,175,170,198,117,169,167,217,147,193,123,7,221,94,231,62,102,180,103,91,20,215,79,37,159,43,67,25,83,41,219,8,114,145,76,27,122,216,35,95,42,123,248,222,215,12,38,25,41,54,242,180,244,33,23,51,140,234,80,29,179,130,232,87,212,94,171,222,193,39,48,164,63,254,173,152,54,218,194,28,205,194,121,143,190,115,42,176,109,58,77,74,246,234,226,233,110,123,82,85,20,106,93,119,91,100,58,227,110,16,219,151,33,52,223,64,236,158,185,37,125,165,173,200,185,67,35,194,159,95,37,239,205,52,116,98,180,154,245,44,237,106,69,102,249,77],\"8\":[61,15,52,84,78,202,205,135,46,28,212,160,230,180,222,30,135,37,211,165,246,221,237,204,48,117,68,116,101,173,175,221,42,93,165,160,147,231,157,120,111,124,33,94,151,239,57,77,66,196,61,53,28,108,130,34,224,130,242,244,7,229,189,175,154,219,130,214,118,99,191,236,69,43,220,182,178,65,205,17,142,36,70,70,76,227,11,249,164,222,44,84,4,87,81,12,61,14,119,32,241,212,93,207,32,17,78,125,187,25,33,206,211,158,140,122,157,40,65,166,205,118,130,186,41,82,133,80,64,30,150,23,201,89,213,134,171,72,150,63,4,168,127,149,62,164,251,158,149,32,139,226,131,219,208,47,19,52,223,144,14,250,50,100,71,30,133,109,255,252,94,55,201,163,122,7,23,128,216,60,226,32,124,123,173,168,44,238,252,199,152,228,113,223,160,87,153,39,129,148,42,105,182,219,53,14,146,229,161,245,129,75,248,134,248,4,0,153,225,14,4,66,212,175,40,19,18,200,133,143,174,53,250,246,93,8,230,180,110,4,109,244,221,56,222,252,247,149,224,171,109,71,172,182,117,238,65,5,224,175,36,63,92,29,122,69,20,11,145,166,192,178,244,93,78,238,5,174,101,131,33,211,123,2,93,244,237,238,158,130,161,159,105,145,180,79,78,119,17,220,22,90,247,253,159,0,212,130,198,24,254,213,213,216,43,67,92,102,4,128,26,86,22,187,0,40,224,134,54,25,21,49,51,217,5,55,148,134,66,35,37,247,66,254,100,23,140,131,84,98,139,127,97,242,78,25,11,89,219,36,208,116,199,216,65,207,72,72,66,177,88,65,239,227,219,205,198,45,79,97,186,179,13,146,152,201,4,30,35,68,202,209,151,79,187,182,146,184,42,211,101,124,55,152,63,205,16,167,19,29,43,200,243,138,248,179,116,200,152,171,101,189,184,136,220,17,227,227,223,29,227,126,7,61,117,42,213,92,138,143,198,201,221,53,234,238,141,13,253,13,227,55,125,70,236,53,133,28,230,183,230,112,46,2,52,227,208,12,23,157,102,199,187,31,150,14,185,96,117,154,163,119,254,166,193,11,18,220,168,202,224,25,226,142,51,139,1,130,115,191,50,73,157,27,80,70,147,172,154,3,210,108,241,63,14,15,4,216,99,192,174,77,98,155,36,32,109,77,49,66,212,188,101,3,161,185,44,125,66,148,45,15,10,231,124,112,29,249,248,245,34,188,109,145,144,80,57,68,46,214,97,129,10,175,244,53,236,233,28,244,108,205,121,45,223,114,244,165,109,96,244,66,23,26,49,231,39,37,23,21,245,160,112,218,197,128,19,181,213,52,64,231,101,191,239,136,142,26,241,228,63,9,148,156,75,213,252,152,60,73,60,112,98,113,39,57,132,232,122,33,105,163,55,247,197,199,90,49,196,246,206,227,1,157,214,6,204,187,209,115,129,56,225,199,180,43,231,44,197,209,60,198,13,243,247,152,54,10,131,16,83,61,225,12,169,12,1,114,192,83,8,69,111,236,211,168,46,136,81,63,178,71,183,11,72,14,160,154,176,109,130,254,123,8,249,45,213,123,202,34,52,59,5,99,118,147,51,75,45,182,132,209,121,49,176,102,218,48,209,176,128,232,88,14,7,97,99,127,113,212,88,102,252,252,141,216,37,135,41,143,216,76,69,253,140,227,247,71,159,216,220,255,97,185,146,148,132,115,163,116,116,211,24,187,183,25,207,150,6,204,152,138,189,110,122,42,63,201,52,103,110,139,12,6,13,43,175,188,163,221,184,151,163,41,96,235,134,44,230,18,206,225,195,111,100,99,236,2,246,206,175,9,194,84,128,162,100,130,210,37,44,149,216,161,105,54,81,208,42,233,134,31,69,12,133,194,179,171,213,231,115,80,134,161,193,236,126,88,210,59,9,62,47,189,106,243,60,232,5,105,238,0,163,109,191,221,20,102,205,108,127,178,39,228,229,138,114,202,122,157,208,131,7,177,249,96,5,60,243,170,84,151,10,93,17,188,141,112,209,98,30,158,7,252,100,82,227,181,111,19,208,158,33,60,124,108,214,225,84,92,245,253,244,80,155,245,213,142,104,151,207,71,79,38,137,143,147,171,154,36,36,89,164,157,161,100,63,251,42,137,74,24,1,41,243,119,118,44,163,9,141,57,98,170,79,67,184,44,142,183,210,228,242,137,177,199,69,52,217,17,243,189,14,14,25,236]},\"reachable\":{\"{\\\"addr\\\":[50,49,54,46,49,49,55,46,51,46,54,50,0,0,0,0],\\\"port\\\":63174,\\\"uid_fingerprint\\\":922068108643293997,\\\"info\\\":[116,121,112,101,61,115,99,114,97,109,98,108,101,115,117,105,116,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,70,68,56,68,67,55,69,70,57,50,70,49,70,49,52,68,48,48,67,70,57,68,54,70,54,50,57,55,65,51,52,54,56,66,53,57,69,55,48,55,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,83,111,109,101,40,123,34,112,97,115,115,119,111,114,100,34,58,32,34,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,50,51,52,53,54,55,34,125,41,0]}\":[[6,1],[8,0]],\"{\\\"addr\\\":[49,53,54,46,55,50,46,50,49,57,46,52,57,0,0,0],\\\"port\\\":56030,\\\"uid_fingerprint\\\":8564141605929456761,\\\"info\\\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,68,56,66,67,67,48,69,67,70,69,50,67,57,54,53,65,66,67,50,57,67,54,50,55,70,68,67,69,67,48,66,48,54,67,53,65,68,66,49,54,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}\":[[1,2]],\"{\\\"addr\\\":[49,50,56,46,49,51,57,46,52,52,46,49,53,55,0,0],\\\"port\\\":10839,\\\"uid_fingerprint\\\":16072135124933872676,\\\"info\\\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,55,67,53,65,51,68,67,53,51,49,48,55,53,53,48,54,65,50,52,52,65,51,67,70,49,57,66,53,55,70,52,68,69,52,55,55,67,65,54,51,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}\":[[2,1],[4,0]],\"{\\\"addr\\\":[50,49,50,46,49,54,54,46,49,54,54,46,54,55,0,0],\\\"port\\\":32414,\\\"uid_fingerprint\\\":3643046579853129326,\\\"info\\\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,66,48,56,49,49,56,65,56,48,68,55,54,54,66,65,57,65,56,70,57,65,55,50,50,67,50,54,54,49,52,69,48,54,66,56,54,69,52,67,65,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}\":[[1,0]],\"{\\\"addr\\\":[49,51,50,46,49,56,49,46,49,53,53,46,55,54,0,0],\\\"port\\\":55241,\\\"uid_fingerprint\\\":4215620865531854407,\\\"info\\\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,67,66,70,56,51,51,51,49,54,53,70,49,67,51,53,65,68,70,48,54,66,70,52,50,53,49,48,52,69,56,51,51,65,68,68,65,49,54,53,66,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,32,102,108,97,103,115,61,83,111,109,101,40,123,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}\":[[1,1]],\"{\\\"addr\\\":[49,57,53,46,55,50,46,55,52,46,49,49,55,0,0,0],\\\"port\\\":28746,\\\"uid_fingerprint\\\":8013544061081454931,\\\"info\\\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,50,57,49,49,48,66,55,68,57,69,57,54,48,65,53,67,52,50,56,52,56,55,55,50,65,70,54,50,52,65,51,66,50,55,65,50,68,69,52,69,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,32,102,108,97,103,115,61,83,111,109,101,40,123,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}\":[[2,0],[3,0]],\"{\\\"addr\\\":[49,57,49,46,49,56,48,46,49,48,51,46,50,51,54,0],\\\"port\\\":50309,\\\"uid_fingerprint\\\":17576062521251310994,\\\"info\\\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,70,68,56,68,67,55,69,70,57,50,70,49,70,49,52,68,48,48,67,70,57,68,54,70,54,50,57,55,65,51,52,54,56,66,53,57,69,55,48,55,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}\":[[6,0],[7,0]],\"{\\\"addr\\\":[50,49,54,46,49,49,55,46,51,46,54,50,0,0,0,0],\\\"port\\\":63174,\\\"uid_fingerprint\\\":9189545078772697644,\\\"info\\\":[116,121,112,101,61,115,99,114,97,109,98,108,101,115,117,105,116,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,69,68,67,51,65,65,48,51,70,69,54,69,53,50,66,69,55,55,56,68,68,52,54,70,50,55,68,51,53,56,57,57,51,66,55,65,49,48,65,52,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,115,116,97,98,108,101,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,118,97,108,105,100,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,83,111,109,101,40,123,34,112,97,115,115,119,111,114,100,34,58,32,34,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,50,51,52,53,54,55,34,125,41,0]}\":[[6,2],[9,0]],\"{\\\"addr\\\":[49,51,52,46,50,48,55,46,50,51,53,46,49,48,53,0],\\\"port\\\":9042,\\\"uid_fingerprint\\\":5838789323103363859,\\\"info\\\":[116,121,112,101,61,111,98,102,115,50,32,98,108,111,99,107,101,100,95,105,110,61,123,125,32,112,114,111,116,111,99,111,108,61,116,99,112,32,102,105,110,103,101,114,112,114,105,110,116,61,34,56,48,55,56,70,57,55,66,50,50,49,53,55,69,66,55,49,54,65,69,66,68,53,54,65,57,52,55,54,67,51,55,56,57,57,65,68,70,54,65,34,32,111,114,95,97,100,100,114,101,115,115,101,115,61,78,111,110,101,32,100,105,115,116,114,105,98,117,116,105,111,110,61,104,116,116,112,115,32,102,108,97,103,115,61,83,111,109,101,40,123,34,118,97,108,105,100,34,58,32,116,114,117,101,44,32,34,114,117,110,110,105,110,103,34,58,32,116,114,117,101,44,32,34,102,97,115,116,34,58,32,116,114,117,101,44,32,34,115,116,97,98,108,101,34,58,32,116,114,117,101,125,41,32,112,97,114,97,109,115,61,78,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]}\":[[2,2],[5,0]]},\"spares\":[1],\"unallocated_bridges\":[],\"recycleable_keys\":[],\"blocked_keys\":[],\"open_inv_keys\":[[3,2460195],[4,2460195],[5,2460195],[7,2460195],[8,2460195],[9,2460195]],\"date_last_enc\":2460195},\"trustup_migration_table\":{\"table\":{\"7\":6,\"8\":6,\"4\":2,\"9\":6,\"3\":2,\"5\":2},\"migration_type\":[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},\"blockage_migration_table\":{\"table\":{},\"migration_type\":[1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]},\"openinv_filter\":{\"seen_table\":[[34,155,156,133,153,119,92,150,172,38,54,150,219,251,139,195,56,83,13,212,134,136,136,104,166,12,221,138,41,4,223,12]]},\"id_filter\":{\"seen_table\":[]},\"inv_id_filter\":{\"seen_table\":[]},\"trust_promotion_filter\":{\"seen_table\":[]}},\"extra_bridges\":[],\"to_be_replaced_bridges\":[]}";
        let test_context: LoxServerContext = serde_json::from_str(&test_string).unwrap();
        lox_db.write_context(test_context);
        assert!(
            lox_db.db.len() == 1,
            "db should have written only one context"
        );
    }
}
